@@ -1,12 +1,16 @@
+from enum import unique
+
 from ts_t1_validator.models.enums.abstract_enum import AbstractEnum
 
 
+@unique
 class PercentageGoalTypeEnum(AbstractEnum):
     CTR = "ctr"
     VCR = "vcr"
     VR = "viewability_rate"
 
 
+@unique
 class FixedGoalTypeEnum(AbstractEnum):
     CPA = "cpa"
     CPC = "cpc"
@@ -16,6 +20,7 @@ class FixedGoalTypeEnum(AbstractEnum):
     VCPM = "vcpm"
 
 
+@unique
 class GoalTypeEnum(AbstractEnum):
     CPA = "cpa"
     CPC = "cpc"
