@@ -5,10 +5,8 @@ from ts_t1_validator.models.enums.frequency_interval import FrequencyIntervalEnu
 
 
 class FrequencyRequiredFieldsRule(ValidationRule):
-    def __init__(self, frequency_type, frequency_optimization, frequency_interval, frequency_amount, cap_fields={}):
-        assert isinstance(frequency_type, FrequencyTypeEnum)
-        assert isinstance(frequency_interval, FrequencyIntervalEnum)
-
+    def __init__(self, frequency_type: FrequencyTypeEnum, frequency_optimization: bool,
+                 frequency_interval: FrequencyIntervalEnum, frequency_amount, cap_fields=dict):
         self.frequency_type = frequency_type
         self.frequency_optimization = frequency_optimization
         self.frequency_amount = frequency_amount
