@@ -40,4 +40,4 @@ class TargetingLocationsInList(ValidationRule):
                     errors.append(value)
 
         if errors:
-            raise ValidationException(f"Some IDs - {errors} does not exist for {self.field_name} section in {self.location_type.value}")
+            raise ValidationException(f"IDs - {errors} does not exist for {self.field_name} section in {self.location_type.value}")
